# AdviserResultResponseResultReportDependencyGraph

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**edges** | **list[list[int]]** | Edge represented as a source-destination pair, representing indexes to the nodes listing  |
**nodes** | **list[str]** | A listing of nodes (package names) in the dependency graph  |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

